@@ -1,21 +1,6 @@
 from enum import IntEnum
 from .utils import assert_enum_value_in_dict, assert_non_empty_string_in_dict
 
-class LabelType(IntEnum):
-    Unknown = 0
-    Custom = 1
-    ProtocolAttack = 2
-    Scam = 3
-    RugPull = 4
-    Bridge = 5
-    Mixer = 6
-    Dex = 7
-    Cex = 8
-    Attacker = 9
-    Victim = 10
-    Eoa = 11
-    Contract = 12
-    Good = 13
 
 class EntityType(IntEnum):
     Unknown = 0
@@ -24,14 +9,19 @@ class EntityType(IntEnum):
     Block = 3
     Url = 4
 
+
 class Label:
     def __init__(self, dict):
         assert_enum_value_in_dict(dict, 'entity_type', EntityType)
-        assert_enum_value_in_dict(dict, 'label_type', LabelType)
         assert_non_empty_string_in_dict(dict, 'entity')
+        assert_non_empty_string_in_dict(dict, 'label')
         self.entity = dict['entity']
         self.confidence = dict['confidence']
-        self.customValue = dict['custom_value']
         self.entity_type = dict['entity_type']
-        self.label_type = dict['label_type']
+        self.label = dict['label']
 
+    def toDict(self):
+        d = dict(self.__dict__, **{
+            'entityType': self.entity_type,
+        })
+        return {k: v for k, v in d.items() if v is not None}
